@@ -303,7 +303,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                         + 'mmButton';
                     this.addOwnedQxObject(mmButton, mmBtnId);
                 }
-                let action = function () {
+                var action = function () {
                     var that = this;
                     if (!button.isEnabled()) {
                         return;
@@ -460,14 +460,21 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                         default:
                             this.debug('Invalid execute action:' + btCfg.action);
                     }
-                }; // action_code
-                // wrap action such that it executes only after the event loop is free again
-                //var action = () => setTimeout(action_code.bind(this),0);
+                }; // var action = function() { ... };
 
                 if (btCfg.defaultAction) {
                     this._defaultAction = action;
                 }
                 if (button) {
+                    // in ios/android buttons do not necessarily get focus when clicked
+                    // so we need to do it manually
+                    let os = qx.core.Environment.get('os.name');
+                    if (os == 'android' || os == 'ios'){
+                        let orig_action = action;
+                        action = () => {
+                            setTimeout(orig_action.bind(this),1);
+                        }
+                    }        
                     button.addListener('execute', action, this);
                     if (btCfg.addToMenu) {
                         menues[btCfg.addToMenu].add(button);
